// $Id: TextPosition.h,v 1.6 2009/03/24 23:48:26 hpereira Exp $

#ifndef TextPosition_h
#define TextPosition_h

/******************************************************************************
*                         
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>             
*                         
* This is free software; you can redistribute it and/or modify it under the    
* terms of the GNU General Public License as published by the Free Software    
* Foundation; either version 2 of the License, or (at your option) any later   
* version.                             
*                          
* This software is distributed in the hope that it will be useful, but WITHOUT 
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or        
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License        
* for more details.                     
*                          
* You should have received a copy of the GNU General Public License along with 
* software; if not, write to the Free Software Foundation, Inc., 59 Temple     
* Place, Suite 330, Boston, MA  02111-1307 USA                           
*                         
*                         
*******************************************************************************/
 
/*!
  \file TextPosition.h
  \brief stores paragraph and index into unique structure
  \author Hugo Pereira
  \version $Revision: 1.6 $
  \date $Date: 2009/03/24 23:48:26 $
*/

#include <QTextStream>

#include "Counter.h"

//! stores paragraph and index (in paragraph) into unique structure
class TextPosition: public Counter
{
  public:
  
  //! default constructor
  TextPosition( int paragraph = 0, int index = 0 ):
    Counter( "TextPosition" ),
    paragraph_( paragraph ),
    index_( index )
  {}
    
  //! paragraph
  const int& paragraph( void ) const
  { return paragraph_; }

  //! paragraph
  int& paragraph( void )
  { return paragraph_; }
  
  //! index
  const int& index( void ) const
  { return index_; }
  

  //! index
  int& index( void )
  { return index_; }
  
  //! lower than operater
  bool operator < (const TextPosition& position ) const
  {
    if( paragraph() != position.paragraph() ) return paragraph() < position.paragraph();
    else return index() < position.index();      
  }
  
  //! greater than operator
  bool operator > (const TextPosition& position ) const
  {
    if( paragraph() != position.paragraph() ) return paragraph() > position.paragraph();
    else return index() > position.index();      
  }
  
  //! lower than operater
  bool operator <= (const TextPosition& position ) const
  { return !(*this > position ); }
  
  //! larger than operater
  bool operator >= (const TextPosition& position ) const
  { return !(*this < position ); }
  
  //! equal operator
  bool operator == (const TextPosition& position ) const
  { return (paragraph() == position.paragraph() && index() == position.index()); }
  
  //! equal operator
  bool operator != (const TextPosition& position ) const
  { return !( *this == position ); }

  //! validity
  bool isValid( void ) const
  { return (paragraph() >= 0 && index() >= 0 ); }
      
  private:
      
  //! paragraph index
  int paragraph_; 
  
  //! character index
  int index_;

  //! dump to stream
  friend QTextStream& operator << ( QTextStream& out, const TextPosition& position )
  {
    out << "(" << position.paragraph() << "," << position.index() << ")";
    return out;
  } 
      
};

#endif
