// $Id: Application.cpp,v 1.21 2009/06/11 05:31:56 hpereira Exp $

/******************************************************************************
*												 
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>						 
*												 
* This is free software; you can redistribute it and/or modify it under the		
* terms of the GNU General Public License as published by the Free Software		
* Foundation; either version 2 of the License, or (at your option) any later	 
* version.														 
* 												 
* This software is distributed in the hope that it will be useful, but WITHOUT 
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or				
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License				
* for more details.										 
* 												 
* You should have received a copy of the GNU General Public License along with 
* software; if not, write to the Free Software Foundation, Inc., 59 Temple		 
* Place, Suite 330, Boston, MA	02111-1307 USA													 
*												 
*												 
*******************************************************************************/
 
/*!
  \file Application.cc
  \brief display application manager server messages
  \author Hugo Pereira
  \version $Revision: 1.21 $
  \date $Date: 2009/06/11 05:31:56 $
*/

#include "BaseIcons.h"
#include "Client.h"
#include "ConfigurationDialog.h"
#include "Debug.h"
#include "File.h"
#include "IconEngine.h"
#include "Application.h"
#include "XmlOptions.h"
#include "QtUtil.h"
#include "ServerCommand.h"
#include "StatusBar.h"
#include "MainWindow.h"
#include "TreeView.h"

using namespace std;
using namespace Qt;
using namespace SERVER;

//____________________________________________
void Application::usage( void )
{
  Debug::Throw(0) << "usage : serverlog [options]" << endl;
  SERVER::ApplicationManager::usage();
  return;
}

//___________________________________________
Application::Application( CommandLineArguments arguments ):
  BaseApplication( 0, arguments ),
  Counter( "Application" ),
  main_window_( 0 )
{}

//___________________________________________
Application::~Application( void )
{}

//___________________________________________
bool Application::realizeWidget( void )
{

  Debug::Throw( "Application::RealizeWidget.\n" );
  if( !BaseApplication::realizeWidget() ) return false;
  
  // rename about action
  aboutAction().setText( "About &serverlog" );
  configurationAction().setText( "&Configure Serverlog..." );
  main_window_ = new MainWindow( 0 );
  mainWindow().setWindowTitle( "Server Log" );
  
  connect( &mainWindow(), 
    SIGNAL( requestCommand( SERVER::ServerCommand::CommandType ) ), 
    SLOT( _sendRequest(  SERVER::ServerCommand::CommandType ) ) );

  connect( &mainWindow(), 
    SIGNAL( requestCommand( SERVER::ServerCommand ) ), 
    SLOT( _sendRequest(  SERVER::ServerCommand ) ) );

  connect( 
    &_applicationManager(), SIGNAL( initialized() ), 
    &mainWindow().resetAction(), SLOT( trigger() ) );
  
  // update configuration
  emit configurationChanged();
  
  // send first request (to identify all applications)
  _requestIdentify();

  // show main widget
  mainWindow().centerOnDesktop();
  mainWindow().show();
    
  return true;
  
}

//___________________________________________
void Application::initApplicationManager( void )
{

  Debug::Throw( "Application::initApplicationManager.\n" ); 

  // make sure application manager does not already exist
  if( _hasApplicationManager() ) return;
  BaseApplication::initApplicationManager();
  
  connect( &_applicationManager().client(), SIGNAL( commandAvailable( SERVER::ServerCommand ) ), SLOT( _append( SERVER::ServerCommand ) ) );
    
}

//_______________________________________________
void Application::_configuration( void )
{
  
  Debug::Throw( "Application::_configuration.\n" );

  // save configuration
  emit saveConfiguration();

  ConfigurationDialog dialog(0);
  connect( &dialog, SIGNAL( configurationChanged() ), SIGNAL( configurationChanged() ) );
  dialog.centerOnWidget( qApp->activeWindow() );
  dialog.exec();
  
}

//__________________________________________________________________
void Application::_sendRequest( SERVER::ServerCommand command ) 
{
  Debug::Throw( "Application::_sendRequest.\n" );
  _applicationManager().client().sendCommand( command );
  return;  
}
  
//___________________________________________
void Application::_append( SERVER::ServerCommand command )
{ 

  Debug::Throw( "Application::_append.\n" );
  
  if( !main_window_ ) return;

  ServerCommandModel::Set commands;
  commands.insert( command );
  mainWindow().append( commands );
    
}

//________________________________________________
bool Application::_processCommand( SERVER::ServerCommand command )
{

  Debug::Throw( "Application::_processCommand.\n" );
  if( BaseApplication::_processCommand( command ) ) return true;
  if( command.command() == SERVER::ServerCommand::RAISE )
  {
    if( main_window_ ) mainWindow().uniconify();
    return true;
  } else return false;

}
