// $Id: Application.h,v 1.11 2009/05/30 17:47:17 hpereira Exp $

/******************************************************************************
*												 
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>						 
*												 
* This is free software; you can redistribute it and/or modify it under the		
* terms of the GNU General Public License as published by the Free Software		
* Foundation; either version 2 of the License, or (at your option) any later	 
* version.														 
* 												 
* This software is distributed in the hope that it will be useful, but WITHOUT 
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or				
* FITNESS FOR A PARTICULAR PURPOSE.	See the GNU General Public License				
* for more details.										 
* 												 
* You should have received a copy of the GNU General Public License along with 
* software; if not, write to the Free Software Foundation, Inc., 59 Temple		 
* Place, Suite 330, Boston, MA	02111-1307 USA													 
*												 
*												 
*******************************************************************************/
 
/*!
  \file Application.h
  \brief display application manager server messages
  \author Hugo Pereira
  \version $Revision: 1.11 $
  \date $Date: 2009/05/30 17:47:17 $
*/

#ifndef Application_h
#define Application_h

#include <cassert>
#include <QModelIndex>

#include "BaseApplication.h"
#include "CommandLineArguments.h"
#include "Counter.h"

class MainWindow;

//! display application manager server messages
class Application: public BaseApplication, public Counter
{

  //! Qt meta object declaration
  Q_OBJECT
  
  public:

  //! usage
  static void usage( void );
    
  //! constructor
  Application( CommandLineArguments );
  
  //! destructor
  ~Application( void );

  //! initialize application manager
  void initApplicationManager( void );
  
  //! create all widgets
  bool realizeWidget( void );

  //! command list
  MainWindow& mainWindow( void )
  { 
    assert( main_window_ );
    return *main_window_; 
  }	
  
  protected slots:
  
  //! configuration
  void _configuration( void );

  //! about
  virtual void _about( void )
  { BaseApplication::_about( "serverlog", VERSION ); }
  
  //! pass command to application manager
  void _sendRequest( SERVER::ServerCommand::CommandType type )
  { if( _hasApplicationManager() ) _sendRequest( SERVER::ServerCommand( _applicationManager().id(), type ) ); }
  
  //! request identification
  void _requestIdentify( void )
  { _sendRequest( SERVER::ServerCommand::IDENTIFY ); }
  
  //! pass command to application manager
  void _sendRequest( SERVER::ServerCommand );
  
  //! append message to the log
  void _append( SERVER::ServerCommand );
 
  //! process request from application manager
  virtual bool _processCommand( SERVER::ServerCommand );
    
  private:
   
  //! main window
  MainWindow* main_window_;

};

#endif
