// $Id: ConfigurationDialog.cpp,v 1.23 2009/04/06 10:18:40 hpereira Exp $

/******************************************************************************
*									       
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>			       
*									       
* This is free software; you can redistribute it and/or modify it under the    
* terms of the GNU General Public License as published by the Free Software    
* Foundation; either version 2 of the License, or (at your option) any later   
* version.							               
* 									       
* This software is distributed in the hope that it will be useful, but WITHOUT 
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or        
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License        
* for more details.							       
* 									       
* You should have received a copy of the GNU General Public License along with 
* software; if not, write to the Free Software Foundation, Inc., 59 Temple     
* Place, Suite 330, Boston, MA  02111-1307 USA		                       
*									       
*									       
*******************************************************************************/
 
/*!
  \file ConfigurationDialog.cc
  \brief xMaze configuration dialog
  \author Hugo Pereira
  \version $Revision: 1.23 $
  \date $Date: 2009/04/06 10:18:40 $
*/

#include <QLabel>
#include <QToolTip>
#include <QGroupBox>
#include <QLayout>

#include "Application.h"
#include "ConfigurationDialog.h"
#include "Debug.h"
#include "GridLayout.h"
#include "MainWindow.h"
#include "OptionComboBox.h"
#include "OptionColorDisplay.h"
#include "OptionSpinBox.h"
#include "Options.h"
#include "QtUtil.h"
#include "ServerConfiguration.h"
#include "Singleton.h"
#include "TreeView.h"
#include "TreeViewConfiguration.h"

using namespace std;

//_________________________________________________________
ConfigurationDialog::ConfigurationDialog( QWidget* parent ):
  BaseConfigurationDialog( parent )
{
  
  
  Debug::Throw( "ConfigurationDialog::ConfigurationDialog.\n" );
  setWindowTitle( "Configuration - serverlog" );

  // base configuration
  baseConfiguration( 0 );

  
  // generic objects
  QGroupBox *box;
  
  // appearance
  QWidget* page = &addPage( "Appearance", "Main window appearance and colors" );
    
  page->layout()->addWidget( box = new QGroupBox( "Colors",  page ) );
  GridLayout* grid_layout = new GridLayout();
  grid_layout->setSpacing(5);
  grid_layout->setMargin(5);
  grid_layout->setMaxCount(2);
  grid_layout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
  box->setLayout( grid_layout );
  
  // colors
  grid_layout->addWidget( new QLabel( "Server application: ", box ) );
  OptionColorDisplay* color = new OptionColorDisplay( box, "SERVER_COLOR" );
 	color->setToolTip( "Item color for server application" );
  grid_layout->addWidget( color );
  addOptionWidget( color );

  grid_layout->addWidget( new QLabel( "Identify requests: ", box ) );
  color = new OptionColorDisplay( box, "IDENTIFY_COLOR" );
 	color->setToolTip( "Item color for identification requests" );
  grid_layout->addWidget( color );
  addOptionWidget( color );
  
  page->layout()->addWidget( box = new QGroupBox( "Misc",  page ) );
  box->setLayout( new QVBoxLayout() );
  box->layout()->setMargin(5);
  box->layout()->setSpacing(5);
  
  grid_layout = new GridLayout();
  grid_layout->setMargin(0);
  grid_layout->setSpacing(5);
  grid_layout->setMaxCount(2);
  box->layout()->addItem( grid_layout );
    
  // verbosity
  grid_layout->addWidget( new QLabel( "Verbosity: ", box ) );
  OptionComboBox* combobox = new OptionComboBox( box, "VERBOSITY" );
  combobox->addItem( MainWindow::VERBOSITY_LOW );
  combobox->addItem( MainWindow::VERBOSITY_HIGH );
  grid_layout->addWidget( combobox );
  addOptionWidget( combobox );
  combobox->setToolTip( "List display verbosity" );

  SERVER::ServerConfiguration* server_configuration;

  page = &addPage( "Server", "Client/server connection to other server-oriented applications" );
  page->layout()->addWidget( server_configuration = new SERVER::ServerConfiguration( page ));
  addOptionWidget( server_configuration );

  // load initial configuration	
  _read();

}
